@@ -2,28 +2,29 @@ from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingCons
 from logging.handlers import RotatingFileHandler
 import logging
 import os
+import sys
 loggingConstants = LoggingConstants()
 class CreateLoggerController:
-    def __init__(self, loggername):
-        self.currentpath = os.path.dirname(os.path.realpath(__file__))
+    def __init__(self, loggername, logging_constants = loggingConstants):
         self.logger = logging.getLogger(loggername)
         self.logger.propagate = True
-        log_format = logging.Formatter(loggingConstants.LOGFORMAT)
+        log_format = logging.Formatter(logging_constants.LOGFORMAT)
         self.logger.setLevel(logging.DEBUG)
-        self.logger.addHandler(self.newHandler(loggingConstants.DEBUGLOG, logging.DEBUG, log_format))
-        self.logger.addHandler(self.newHandler(loggingConstants.WARNINGLOG, logging.WARNING, log_format))
-        self.logger.addHandler(self.newHandler(loggingConstants.INFOLOG, logging.INFO, log_format))
+        self.logger.addHandler(self.newHandler(logging_constants.DEBUGLOG, logging.DEBUG, log_format, logging_constants))
+        self.logger.addHandler(self.newHandler(logging_constants.ERRORLOG, logging.ERROR, log_format, logging_constants))
+        self.logger.addHandler(self.newHandler(logging_constants.INFOLOG, logging.INFO, log_format, logging_constants))
+        self.logger.addHandler(logging.StreamHandler(sys.stdout))
         """console = logging.StreamHandler(sys.stdout)
         console.setFormatter(log_format)
         console.setLevel(logging.DEBUG)
         self.logger.info('test')
         self.logger.addHandler(console)"""
 
-    def newHandler(self, filename, log_level, log_format):
+    def newHandler(self, filename, log_level, log_format, logging_constants):
         handler = RotatingFileHandler(
             filename,
-            maxBytes=loggingConstants.MAXFILESIZE,
-            backupCount=loggingConstants.BACKUPCOUNT
+            maxBytes=logging_constants.MAXFILESIZE,
+            backupCount=logging_constants.BACKUPCOUNT
         )
         handler.setFormatter(log_format)
         handler.setLevel(log_level)
