@@ -99,6 +99,17 @@ class EventVariables:
         cls.how = 'h-g-i-g-o'
         return cls
 
+    @classmethod
+    def DeleteVideo(cls):
+        cls.uid = None
+        cls.version = '2.0'
+        cls.type = 't-x-d-d'
+        cls.time = None
+        cls.start = None
+        cls.stale = None
+        cls.how = 'h-g-i-g-o'
+        return cls
+
     @classmethod
     def takPong(cls):
         cls.version = '2.0'
@@ -144,13 +155,67 @@ class EventVariables:
         return cls
 
     @classmethod
-    def CreateExCheckTemplate(cls):
+    def ExcheckUpdate(cls):
         cls.version = None
         cls.uid = None
-        cls.type = None
+        cls.type = "t-x-m-c"
         cls.time = None
         cls.start = None
         cls.stale = None
-        cls.how = None
+        cls.how = "h-g-i-g-o"
         return cls
 
+    @classmethod
+    def Route(cls):
+        cls.version = None
+        cls.uid = None
+        cls.type = "b-m-r"
+        cls.time = None
+        cls.start = None
+        cls.stale = None
+        cls.how = "h-e"
+        return cls
+
+    @classmethod
+    def VideoStream(cls):
+        cls.version = None
+        cls.uid = None
+        cls.type = "b-i-v"
+        cls.time = None
+        cls.start = None
+        cls.stale = None
+        cls.how = "m-g"
+        return cls
+
+    @classmethod
+    def DroneSensor(cls):
+        cls.version = None
+        cls.uid = None
+        cls.type = "a-f-A-M-H-Q"
+        cls.time = None
+        cls.start = None
+        cls.stale = None
+        cls.how = "m-g"
+        return cls
+
+    @classmethod
+    def BitsImageryVideo(cls):
+        cls.version = None
+        cls.uid = None
+        cls.type = "b-i-v"
+        cls.time = None
+        cls.start = None
+        cls.stale = None
+        cls.how = "m-g"
+        return cls
+
+    @classmethod
+    def SPISensor(cls):
+        cls.version = None
+        cls.uid = None
+        cls.type = "b-m-p-s-p-i"
+        cls.time = None
+        cls.start = None
+        cls.stale = None
+        cls.how = "m-g"
+        return cls
\ No newline at end of file
